==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/AssigningCategoryMarkerStyleEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AssigningCategoryStyleEventArgsBaseDescriptionMetadata } from "./AssigningCategoryStyleEventArgsBaseDescriptionMetadata";
import { AssigningCategoryMarkerStyleEventArgsDescription } from "./AssigningCategoryMarkerStyleEventArgsDescription";
/**
 * @hidden
 */
export let AssigningCategoryMarkerStyleEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class AssigningCategoryMarkerStyleEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (AssigningCategoryMarkerStyleEventArgsDescriptionMetadata.a == null) {
                AssigningCategoryMarkerStyleEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                AssigningCategoryMarkerStyleEventArgsDescriptionMetadata.c(AssigningCategoryMarkerStyleEventArgsDescriptionMetadata.a);
            }
            if (a.k(AssigningCategoryMarkerStyleEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(AssigningCategoryMarkerStyleEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            AssigningCategoryStyleEventArgsBaseDescriptionMetadata.c(a);
        }
        static d(a) {
            AssigningCategoryMarkerStyleEventArgsDescriptionMetadata.b(a);
            a.ad("AssigningCategoryMarkerStyleEventArgs", () => new AssigningCategoryMarkerStyleEventArgsDescription());
            a.ac("AssigningCategoryMarkerStyleEventArgs", AssigningCategoryMarkerStyleEventArgsDescriptionMetadata.a);
        }
    }
    AssigningCategoryMarkerStyleEventArgsDescriptionMetadata.$t = markType(AssigningCategoryMarkerStyleEventArgsDescriptionMetadata, 'AssigningCategoryMarkerStyleEventArgsDescriptionMetadata');
    AssigningCategoryMarkerStyleEventArgsDescriptionMetadata.a = null;
    return AssigningCategoryMarkerStyleEventArgsDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/AssigningCategoryMarkerStyleEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AssigningCategoryStyleEventArgsBaseDescriptionMetadata } from "./AssigningCategoryStyleEventArgsBaseDescriptionMetadata";
import { AssigningCategoryMarkerStyleEventArgsDescription } from "./AssigningCategoryMarkerStyleEventArgsDescription";
/**
 * @hidden
 */
export let AssigningCategoryMarkerStyleEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class AssigningCategoryMarkerStyleEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (AssigningCategoryMarkerStyleEventArgsDescriptionMetadata.a == null) {
                AssigningCategoryMarkerStyleEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                AssigningCategoryMarkerStyleEventArgsDescriptionMetadata.c(AssigningCategoryMarkerStyleEventArgsDescriptionMetadata.a);
            }
            if (a.k(AssigningCategoryMarkerStyleEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(AssigningCategoryMarkerStyleEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            AssigningCategoryStyleEventArgsBaseDescriptionMetadata.c(a);
        }
        static d(a) {
            AssigningCategoryMarkerStyleEventArgsDescriptionMetadata.b(a);
            a.ae("AssigningCategoryMarkerStyleEventArgs", () => new AssigningCategoryMarkerStyleEventArgsDescription());
            a.ad("AssigningCategoryMarkerStyleEventArgs", AssigningCategoryMarkerStyleEventArgsDescriptionMetadata.a);
        }
    }
    AssigningCategoryMarkerStyleEventArgsDescriptionMetadata.$t = markType(AssigningCategoryMarkerStyleEventArgsDescriptionMetadata, 'AssigningCategoryMarkerStyleEventArgsDescriptionMetadata');
    AssigningCategoryMarkerStyleEventArgsDescriptionMetadata.a = null;
    return AssigningCategoryMarkerStyleEventArgsDescriptionMetadata;
})();
